@@ -7,6 +7,7 @@
 #include "messagecomposer/helper/messagefactory.h"
 #include "messagelist/core/view.h"
 #include "search/searchpattern.h"
+#include "messageviewer/viewer/viewer.h"
 
 #include <akonadi/kmime/messagestatus.h>
 #include <kio/job.h>
@@ -301,7 +302,7 @@ public:
       @param parent  The parent widget of the command used for message boxes.
       @param msg     The message of which the attachments should be saved.
    */
-    KMSaveAttachmentsCommand( QWidget *parent, const Akonadi::Item &msg  );
+    KMSaveAttachmentsCommand( QWidget *parent, const Akonadi::Item &msg, MessageViewer::Viewer *viewer  );
     /** Use this to save all attachments of the given messages.
       @param parent  The parent widget of the command used for message boxes.
       @param msgs    The messages of which the attachments should be saved.
@@ -310,6 +311,7 @@ public:
 
 private:
     virtual Result execute();
+    MessageViewer::Viewer *mViewer;
 };
 
 
@@ -386,7 +388,7 @@ public:
     KMPrintCommand( QWidget *parent, const Akonadi::Item &msg,
                     MessageViewer::HeaderStyle *headerStyle = 0,
                     MessageViewer::HeaderStrategy *headerStrategy = 0,
-                    bool htmlOverride = false,
+                    MessageViewer::Viewer::DisplayFormatMessage format = MessageViewer::Viewer::UseGlobalSetting,
                     bool htmlLoadExtOverride = false,
                     bool useFixedFont = false,
                     const QString & encoding = QString() );
@@ -403,7 +405,7 @@ private:
     const MessageViewer::AttachmentStrategy *mAttachmentStrategy;
     QFont mOverrideFont;
     QString mEncoding;
-    bool mHtmlOverride;
+    MessageViewer::Viewer::DisplayFormatMessage mFormat;
     bool mHtmlLoadExtOverride;
     bool mUseFixedFont;
     bool mPrintPreview;
