@@ -59,7 +59,6 @@
 #include <kpimutils/email.h>
 #include <kmime/kmime_message.h>
 
-#include <messageviewer/viewer/viewer.h>
 #include <akonadi/item.h>
 #include <akonadi/itemcopyjob.h>
 #include <akonadi/itemcreatejob.h>
@@ -69,13 +68,13 @@
 
 using namespace MailCommon;
 
-KMReaderMainWin::KMReaderMainWin( bool htmlOverride, bool htmlLoadExtOverride,
+KMReaderMainWin::KMReaderMainWin(MessageViewer::Viewer::DisplayFormatMessage format, bool htmlLoadExtOverride,
                                   char *name )
     : KMail::SecondaryWindow( name ? name : "readerwindow#" )
 {
     mReaderWin = new KMReaderWin( this, this, actionCollection());
     //mReaderWin->setShowCompleteMessage( true );
-    mReaderWin->setHtmlOverride( htmlOverride );
+    mReaderWin->setDisplayFormatMessageOverwrite( format );
     mReaderWin->setHtmlLoadExtOverride( htmlLoadExtOverride );
     mReaderWin->setDecryptMessageOverwrite( true );
     initKMReaderMainWin();
@@ -92,12 +91,12 @@ KMReaderMainWin::KMReaderMainWin( char *name )
 
 
 //-----------------------------------------------------------------------------
-KMReaderMainWin::KMReaderMainWin(KMime::Content* aMsgPart, bool aHTML, const QString & encoding, char *name )
+KMReaderMainWin::KMReaderMainWin(KMime::Content* aMsgPart, MessageViewer::Viewer::DisplayFormatMessage format, const QString & encoding, char *name )
     : KMail::SecondaryWindow( name ? name : "readerwindow#" )
 {
     mReaderWin = new KMReaderWin( this, this, actionCollection() );
     mReaderWin->setOverrideEncoding( encoding );
-    mReaderWin->setHtmlOverride( aHTML );
+    mReaderWin->setDisplayFormatMessageOverwrite( format );
     mReaderWin->setMsgPart( aMsgPart );
     initKMReaderMainWin();
 }
@@ -577,6 +576,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item&msg ,const KUrl&url,c
             if ( msg.isValid() ) {
                 menu->addSeparator();
                 menu->addAction( mReaderWin->createTodoAction() );
+                menu->addAction( mReaderWin->createEventAction() );
                 menu->addSeparator();
                 menu->addAction( mReaderWin->saveMessageDisplayFormatAction() );
                 menu->addAction( mReaderWin->resetMessageDisplayFormatAction() );
