@@ -46,6 +46,7 @@
 #include "print/knoteprintobject.h"
 #include "knotesglobalconfig.h"
 #include "dialog/knoteskeydialog.h"
+#include "dialog/knotedeleteselectednotesdialog.h"
 #include "print/knoteprintselectednotesdialog.h"
 #include "finddialog/knotefinddialog.h"
 
@@ -81,6 +82,7 @@
 #include <kwindowsystem.h>
 #include <kxmlguibuilder.h>
 #include <kxmlguifactory.h>
+#include <KFileDialog>
 
 #include <kiconloader.h>
 
@@ -126,6 +128,12 @@ KNotesApp::KNotesApp()
     action->setGlobalShortcut( KShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_C ));
     connect( action, SIGNAL(triggered()), SLOT(newNoteFromClipboard()) );
 
+    action  = new KAction( KIcon( QLatin1String("document-open") ),
+                           i18n( "New Note From Text File..." ), this );
+    actionCollection()->addAction( QLatin1String("new_note_from_text_file"), action );
+    connect( action, SIGNAL(triggered()), SLOT(newNoteFromTextFile()) );
+
+
     action  = new KAction( KIcon(QLatin1String( "knotes") ), i18n( "Show All Notes" ), this );
     actionCollection()->addAction( QLatin1String("show_all_notes"), action );
     action->setGlobalShortcut( KShortcut( Qt::ALT + Qt::SHIFT + Qt::Key_S ));
@@ -142,6 +150,11 @@ KNotesApp::KNotesApp()
     actionCollection()->addAction( QLatin1String("print_selected_notes"), action );
     connect( action, SIGNAL(triggered()), SLOT(slotPrintSelectedNotes()) );
 
+    action = new KAction( KIcon( QLatin1String("edit-delete") ),
+                          i18nc( "@action:inmenu", "Delete Selected Notes..." ), this );
+    actionCollection()->addAction( QLatin1String("delete_selected_notes"), action );
+    connect( action, SIGNAL(triggered()), SLOT(slotDeleteSelectedNotes()) );
+
     KAction *act = KStandardAction::find( this, SLOT(slotOpenFindDialog()), actionCollection());
     //REmove shortcut here.
     act->setShortcut(0);
@@ -216,6 +229,29 @@ KNotesApp::~KNotesApp()
     m_publisher=0;
 }
 
+void KNotesApp::slotDeleteSelectedNotes()
+{
+    QPointer<KNoteDeleteSelectedNotesDialog> dlg = new KNoteDeleteSelectedNotesDialog(this);
+    Akonadi::Item::List lst;
+    QHashIterator<Akonadi::Item::Id, KNote*> i(mNotes);
+    while (i.hasNext()) {
+        i.next();
+        Akonadi::Item item = i.value()->item();
+        if (!item.hasAttribute<NoteShared::NoteLockAttribute>()) {
+            lst.append(item);
+        }
+    }
+    dlg->setNotes(lst);
+    if (dlg->exec()) {
+        Akonadi::Item::List lst = dlg->selectedNotes();
+        if (!lst.isEmpty()) {
+            Akonadi::ItemDeleteJob *deleteJob = new Akonadi::ItemDeleteJob(lst, this);
+            connect( deleteJob, SIGNAL(result(KJob*)), SLOT(slotNoteDeleteFinished(KJob*)) );
+        }
+    }
+    delete dlg;
+}
+
 void KNotesApp::slotItemRemoved(const Akonadi::Item &item)
 {
     qDebug()<<" note removed"<<item.id();
@@ -355,6 +391,25 @@ void KNotesApp::newNoteFromClipboard( const QString &name )
     newNote( name, text );
 }
 
+void KNotesApp::newNoteFromTextFile()
+{
+    QString text;
+    const QString filename = KFileDialog::getOpenFileName( KUrl(),
+                                     QLatin1String("*.txt"),
+                                     this,
+                                     i18n("Select Text File") );
+    if (!filename.isEmpty()) {
+        QFile f(filename);
+        if (f.open(QIODevice::ReadOnly|QIODevice::Text)) {
+            text = QString::fromUtf8(f.readAll());
+        } else {
+            KMessageBox::error(this, i18n("Error during open text file: %1", f.errorString()), i18n("Open Text File"));
+            return;
+        }
+        newNote( i18n("Note from file '%1'",filename), text);
+    }
+}
+
 void KNotesApp::updateNetworkListener()
 {
     delete m_publisher;
