@@ -197,6 +197,11 @@ KNotesPart::KNotesPart( QObject *parent )
     connect( act, SIGNAL(triggered()), SLOT(slotNewNoteFromClipboard()) );
 
 
+    act  = new KAction( KIcon( QLatin1String("document-open") ),
+                           i18n( "New Note From Text File..." ), this );
+    actionCollection()->addAction( QLatin1String("new_note_from_text_file"), act );
+    connect( act, SIGNAL(triggered()), SLOT(slotNewNoteFromTextFile()) );
+
     mSaveAs  = new KAction( KIcon( QLatin1String("document-save-as") ), i18n( "Save As..." ), this );
     actionCollection()->addAction( QLatin1String("save_note"), mSaveAs );
     connect( mSaveAs, SIGNAL(triggered(bool)), SLOT(slotSaveAs()) );
@@ -206,6 +211,7 @@ KNotesPart::KNotesPart( QObject *parent )
     connect( mReadOnly, SIGNAL(triggered(bool)), SLOT(slotUpdateReadOnly()) );
     mReadOnly->setCheckedState( KGuiItem( i18n( "Unlock" ), QLatin1String("object-unlocked") ) );
 
+
     KStandardAction::find( this, SLOT(slotOpenFindDialog()), actionCollection());
 
     Akonadi::Session *session = new Akonadi::Session( "KNotes Session", this );
@@ -234,6 +240,12 @@ KNotesPart::KNotesPart( QObject *parent )
 
     mNotesWidget = new KNotesWidget(this,widget());
 
+    mQuickSearchAction = new KAction( i18n("Set Focus to Quick Search"), this );
+    //If change shortcut change in quicksearchwidget->lineedit->setClickMessage
+    mQuickSearchAction->setShortcut( QKeySequence( Qt::ALT + Qt::Key_Q ) );
+    actionCollection()->addAction( QLatin1String("focus_to_quickseach"), mQuickSearchAction );
+    connect( mQuickSearchAction, SIGNAL(triggered(bool)), mNotesWidget, SLOT(slotFocusQuickSearch()) );
+
     connect( mNotesWidget->notesView(), SIGNAL(executed(QListWidgetItem*)),
              this, SLOT(editNote(QListWidgetItem*)) );
 
@@ -244,6 +256,7 @@ KNotesPart::KNotesPart( QObject *parent )
     setWidget( mNotesWidget );
     setXMLFile( QLatin1String("knotes_part.rc") );
     updateNetworkListener();
+    updateClickMessage();
 }
 
 KNotesPart::~KNotesPart()
@@ -252,6 +265,11 @@ KNotesPart::~KNotesPart()
     mPublisher=0;
 }
 
+void KNotesPart::updateClickMessage()
+{
+    mNotesWidget->updateClickMessage(mQuickSearchAction->shortcut().toString());
+}
+
 void KNotesPart::slotItemRemoved(const Akonadi::Item &item)
 {
     KNotesIconViewItem *iconView = mNotesWidget->notesView()->iconView(item.id());
@@ -537,9 +555,11 @@ void KNotesPart::editNote( QListWidgetItem *item )
     dlg->setAutoIndentMode(knotesItem->autoIndent());
     dlg->setTextFont(knotesItem->textFont());
 
+    dlg->setCursorPositionFromStart(knotesItem->cursorPositionFromStart());
+
     dlg->noteEdit()->setFocus();
     if ( dlg->exec() == QDialog::Accepted ) {
-        knotesItem->setChangeIconTextAndDescription(dlg->title(), dlg->text());
+        knotesItem->setChangeIconTextAndDescription(dlg->title(), dlg->text(), dlg->cursorPositionFromStart());
     }
     delete dlg;
 }
@@ -840,3 +860,22 @@ void KNotesPart::slotItemFetchFinished(KJob *job)
         mNotesWidget->notesView()->addNote(item);
     }
 }
+
+void KNotesPart::slotNewNoteFromTextFile()
+{
+    QString text;
+    const QString filename = KFileDialog::getOpenFileName( KUrl(),
+                                     QLatin1String("*.txt"),
+                                     widget(),
+                                     i18n("Select Text File") );
+    if (!filename.isEmpty()) {
+        QFile f(filename);
+        if (f.open(QIODevice::ReadOnly|QIODevice::Text)) {
+            text = QString::fromUtf8(f.readAll());
+        } else {
+            KMessageBox::error(widget(), i18n("Error during open text file: %1", f.errorString()), i18n("Open Text File"));
+            return;
+        }
+        newNote( i18n("Note from file '%1'",filename), text);
+    }
+}
