@@ -22,7 +22,7 @@
 #include <KApplication>
 #include <KDebug>
 #include <KIconLoader>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMimeType>
 
 #include <QPixmap>
@@ -148,4 +148,3 @@ void KTNEFView::adjustColumnWidth()
   setColumnWidth( 2, w / 2 );
 }
 
-#include "ktnefview.moc"
