@@ -226,7 +226,9 @@ public:
           m_addressBookConnected( false ),
           m_lastSearchMode( false ),
           m_searchExtended( false ),
-          m_useSemicolonAsSeparator( false )
+          m_useSemicolonAsSeparator( false ),
+          m_showOU(false),
+          m_enableBalooSearch(true)
     {
         m_delayedQueryTimer.setSingleShot(true);
         connect( &m_delayedQueryTimer, SIGNAL(timeout()), q, SLOT(slotTriggerDelayedQueries()) );
@@ -259,6 +261,7 @@ public:
     void slotAkonadiCollectionsReceived( const Akonadi::Collection::List & );
     void searchInBaloo();
     void slotTriggerDelayedQueries();
+    void slotShowOUChanged( bool );
     static KCompletion::CompOrder completionOrder();
 
     AddresseeLineEdit *q;
@@ -271,6 +274,8 @@ public:
     bool m_lastSearchMode;
     bool m_searchExtended; //has \" been added?
     bool m_useSemicolonAsSeparator;
+    bool m_showOU;
+    bool m_enableBalooSearch;
     QTimer m_delayedQueryTimer;
     QColor m_alternateColor;
 };
@@ -287,6 +292,22 @@ void AddresseeLineEdit::Private::init()
             s_static->ldapTimer = new QTimer;
             s_static->ldapSearch = new KLDAP::LdapClientSearch;
 
+            /* The reasoning behind this filter is:
+             * If it's a person, or a distlist, show it, even if it doesn't have an email address.
+             * If it's not a person, or a distlist, only show it if it has an email attribute.
+             * This allows both resource accounts with an email address which are not a person and
+             * person entries without an email address to show up, while still not showing things
+             * like structural entries in the ldap tree.
+             */
+
+            #if 0
+                s_static->ldapSearch->setFilter(QString::fromLatin1("&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))"
+                                                          "(|(cn=%1*)(mail=%1*)(mail=*@%1*)(givenName=%1*)(sn=%1*))"));
+            #endif
+            //Fix bug 323272 "Exchange doesn't like any queries beginning with *."
+            s_static->ldapSearch->setFilter(QString::fromLatin1( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))"
+                                "(|(cn=%1*)(mail=%1*)(givenName=%1*)(sn=%1*))" ));
+
         }
 
         s_static->balooCompletionSource = q->addCompletionSource( i18nc( "@title:group", "Contacts found in your data"), -1 );
@@ -312,6 +333,11 @@ void AddresseeLineEdit::Private::init()
 
             m_completionInitialized = true;
         }
+
+        KConfigGroup group( KGlobal::config(), "AddressLineEdit" );
+        m_showOU = group.readEntry( "ShowOU", false );
+        m_enableBalooSearch = group.readEntry( "EnabledBalooSearch", true );
+
     }
 }
 
@@ -593,8 +619,10 @@ void AddresseeLineEdit::Private::slotTriggerDelayedQueries()
 
 void AddresseeLineEdit::Private::startSearches()
 {
-    //No need to delay the baloo search
-    searchInBaloo();
+    if (m_enableBalooSearch) {
+       //No need to delay the baloo search
+       searchInBaloo();
+    }
 
     if (!m_delayedQueryTimer.isActive())
         m_delayedQueryTimer.start(50);
@@ -792,7 +820,11 @@ void AddresseeLineEdit::Private::slotCompletion()
 
 void AddresseeLineEdit::Private::slotPopupCompletion( const QString &completion )
 {
-    q->setText( m_previousAddresses + completion.trimmed() );
+    QString c = completion.trimmed();
+    if ( c.endsWith( QLatin1Char( ')' ) ) ) {
+        c = completion.mid( 0, completion.lastIndexOf( QLatin1String( " (" )) ).trimmed();
+    }
+    q->setText( m_previousAddresses + c );
     q->cursorAtEnd();
     updateSearchString();
     q->emitTextCompleted();
@@ -838,13 +870,25 @@ void AddresseeLineEdit::Private::slotLDAPSearchData( const KLDAP::LdapResult::Li
         KABC::Addressee contact;
         contact.setNameFromString( result.name );
         contact.setEmails( result.email );
+        QString ou;
+
+        if ( m_showOU ) {
+            const int depth = result.dn.depth();
+            for ( int i = 0; i < depth; ++i ) {
+                const QString rdnStr = result.dn.rdnString( i );
+                if ( rdnStr.startsWith( QLatin1String( "ou=" ), Qt::CaseInsensitive ) ) {
+                    ou = rdnStr.mid( 3 );
+                    break;
+                }
+            }
+        }
 
         if ( !s_static->ldapClientToCompletionSourceMap.contains( result.clientNumber ) ) {
             s_static->updateLDAPWeights(); // we got results from a new source, so update the completion sources
         }
 
         q->addContact( contact, result.completionWeight,
-                       s_static->ldapClientToCompletionSourceMap[ result.clientNumber ] );
+                       s_static->ldapClientToCompletionSourceMap[ result.clientNumber ], ou );
     }
 
     if ( ( q->hasFocus() || q->completionBox()->hasFocus() ) &&
@@ -965,6 +1009,15 @@ KCompletion::CompOrder AddresseeLineEdit::Private::completionOrder()
     }
 }
 
+void AddresseeLineEdit::Private::slotShowOUChanged(bool checked)
+{
+    if ( checked != m_showOU ) {
+        KConfigGroup group( KGlobal::config(), "AddressLineEdit" );
+        group.writeEntry( "ShowOU", checked );
+        m_showOU = checked;
+    }
+}
+
 AddresseeLineEdit::AddresseeLineEdit( QWidget *parent, bool enableCompletion )
     : KLineEdit( parent ), d( new Private( this, enableCompletion ) )
 {
@@ -1232,7 +1285,7 @@ void AddresseeLineEdit::addContactGroup( const KABC::ContactGroup &group, int we
     d->addCompletionItem( group.name(), weight, source );
 }
 
-void AddresseeLineEdit::addContact( const KABC::Addressee &addr, int weight, int source )
+void AddresseeLineEdit::addContact( const KABC::Addressee &addr, int weight, int source, QString append )
 {
     const QStringList emails = addr.emails();
     QStringList::ConstIterator it;
@@ -1246,6 +1299,15 @@ void AddresseeLineEdit::addContact( const KABC::Addressee &addr, int weight, int
         const QString nickName  = addr.nickName();
         QString fullEmail       = addr.fullEmail( email );
 
+        QString appendix;
+
+        if ( !append.isEmpty() ) {
+            appendix = QLatin1String( " (%1)" );
+            append = append.replace( QLatin1String("("), QLatin1String("[") );
+            append = append.replace( QLatin1String(")"), QLatin1String("]") );
+            appendix = appendix.arg( append );
+        }
+
         // Prepare "givenName" + ' ' + "familyName"
         QString fullName = givenName;
         if (!familyName.isEmpty()) {
@@ -1260,7 +1322,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee &addr, int weight, int
             if (fullEmail != address) {
                 // This happens when fullEmail contains a middle name, while our own fullName+email only has "first last".
                 // Let's offer both, the fullEmail with 3 parts, looks a tad formal.
-                d->addCompletionItem(address, weight + isPrefEmail, source);
+                d->addCompletionItem(address + appendix, weight + isPrefEmail, source);
             }
         }
 
@@ -1269,7 +1331,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee &addr, int weight, int
             keyWords.append(nickName);
         }
 
-        d->addCompletionItem( fullEmail, weight + isPrefEmail, source, &keyWords );
+        d->addCompletionItem( fullEmail + appendix, weight + isPrefEmail, source, &keyWords );
 
         isPrefEmail = 0;
     }
@@ -1299,6 +1361,13 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
     if ( d->m_useCompletion ) {
         menu->addAction( i18n( "Configure Completion Order..." ),
                          this, SLOT(slotEditCompletionOrder()) );
+
+        QAction *showOU = new QAction(i18n( "Show Organization Unit for LDAP results" ),menu);
+        showOU->setCheckable(true);
+
+        showOU->setChecked( d->m_showOU );
+        connect(showOU, SIGNAL(triggered(bool)), this, SLOT(slotShowOUChanged(bool)));
+        menu->addAction(showOU);
     }
     return menu;
 }
