@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,6 +24,7 @@ class KLineEdit;
 class QDomElement;
 
 namespace KSieveUi {
+class SieveHelpButton;
 class SieveForEveryPartWidget : public SieveWidgetPageAbstract
 {
     Q_OBJECT
@@ -40,6 +41,7 @@ private Q_SLOTS:
 private:
     QCheckBox *mForLoop;
     KLineEdit *mName;
+    SieveHelpButton *mHelpButton;
 };
 }
 
