@@ -26,8 +26,12 @@
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/sievescriptparsingerrordialog.h"
 
+#include <knewstuff3/uploaddialog.h>
 #include <klocale.h>
 #include <KStandardGuiItem>
+#include <ktempdir.h>
+#include <kzip.h>
+#include <ktemporaryfile.h>
 
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -37,16 +41,21 @@
 #include <QToolBar>
 #include <QDebug>
 #include <QAction>
+#include <QPointer>
+#include <QDir>
+
 
 using namespace KSieveUi;
 
 SieveEditorWidget::SieveEditorWidget(QWidget *parent)
     : QWidget(parent),
-      mMode(TextMode)
+      mMode(TextMode),
+      mModified(false)
 {
     QVBoxLayout *lay = new QVBoxLayout;
 
     QToolBar *bar = new QToolBar;
+    bar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
     connect(mCheckSyntax, SIGNAL(triggered(bool)), SLOT(slotCheckSyntax()));
     bar->addAction(mCheckSyntax);
@@ -66,6 +75,12 @@ SieveEditorWidget::SieveEditorWidget(QWidget *parent)
     bar->addAction(mGenerateXml);
 #endif
 
+    QStringList overlays;
+    overlays <<QLatin1String("list-add");
+    mUpload = new QAction(KIcon(QLatin1String("get-hot-new-stuff"), 0, overlays), i18n("Upload..."), this);
+    connect(mUpload, SIGNAL(triggered(bool)), SLOT(slotUploadScripts()));
+    bar->addAction(mUpload);
+
     lay->addWidget(bar);
 
 
@@ -83,10 +98,10 @@ SieveEditorWidget::SieveEditorWidget(QWidget *parent)
     mStackedWidget = new QStackedWidget;
 
     mTextModeWidget = new SieveEditorTextModeWidget;
-    connect(mTextModeWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
+    connect(mTextModeWidget, SIGNAL(valueChanged()), this, SLOT(slotModified()));
     mStackedWidget->addWidget(mTextModeWidget);
     mGraphicalModeWidget = new SieveEditorGraphicalModeWidget;
-    connect(mGraphicalModeWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
+    connect(mGraphicalModeWidget, SIGNAL(valueChanged()), this, SLOT(slotModified()));
     mStackedWidget->addWidget(mGraphicalModeWidget);
 
     lay->addWidget(mStackedWidget);
@@ -103,6 +118,66 @@ SieveEditorWidget::~SieveEditorWidget()
 {
 }
 
+void SieveEditorWidget::slotModified()
+{
+    mModified = true;
+    Q_EMIT valueChanged(mModified);
+}
+
+bool SieveEditorWidget::isModified() const
+{
+    return mModified;
+}
+
+void SieveEditorWidget::goToLine()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->goToLine();
+    }
+}
+
+SieveEditorWidget::EditorMode SieveEditorWidget::mode() const
+{
+    return mMode;
+}
+
+void SieveEditorWidget::setModified(bool b)
+{
+    if (mModified != b) {
+        mModified = b;
+        Q_EMIT valueChanged(mModified);
+    }
+}
+
+void SieveEditorWidget::slotUploadScripts()
+{
+    KTempDir tmp;
+    KTemporaryFile tmpFile;
+    if (tmpFile.open()) {
+        QTextStream out(&tmpFile);
+        out.setCodec("UTF-8");
+        out << script();
+        tmpFile.close();
+        const QString sourceName = mScriptName->text();
+        const QString zipFileName = tmp.name() + QDir::separator() + sourceName + QLatin1String(".zip");
+        KZip *zip = new KZip(zipFileName);
+        if (zip->open(QIODevice::WriteOnly)) {
+            if (zip->addLocalFile(tmpFile.fileName(), sourceName + QLatin1String(".siv"))) {
+                zip->close();
+                QPointer<KNS3::UploadDialog> dialog = new KNS3::UploadDialog(QLatin1String("ksieve_script.knsrc"), this);
+                dialog->setUploadFile(zipFileName);
+                dialog->setUploadName(sourceName);
+                dialog->setDescription(i18nc("Default description for the source", "My Sieve Script"));
+                dialog->exec();
+                delete dialog;
+            } else {
+                zip->close();
+            }
+        }
+        delete zip;
+    }
+}
+
 void SieveEditorWidget::changeMode(EditorMode mode)
 {
     if (mode != mMode) {
@@ -116,6 +191,7 @@ void SieveEditorWidget::changeMode(EditorMode mode)
             mCheckSyntax->setEnabled(false);
         else
             mCheckSyntax->setEnabled(!mTextModeWidget->currentscript().isEmpty());
+        Q_EMIT modeEditorChanged(mode);
     }
 }
 
@@ -140,6 +216,9 @@ QString SieveEditorWidget::script() const
     case GraphicMode:
         currentScript = mGraphicalModeWidget->currentscript();
         break;
+    case Unknown:
+        qDebug()<<" Unknown Mode!";
+        break;
     }
     return currentScript;
 }
@@ -203,6 +282,7 @@ void SieveEditorWidget::slotAutoGenerateScripts()
         mTextModeWidget->autoGenerateScripts();
         break;
     case GraphicMode:
+    case Unknown:
         break;
     }
 }
@@ -215,6 +295,7 @@ void SieveEditorWidget::slotCheckSyntax()
         Q_EMIT checkSyntax();
         break;
     case GraphicMode:
+    case Unknown:
         break;
     }
 }
@@ -227,6 +308,7 @@ void SieveEditorWidget::slotGenerateXml()
         mTextModeWidget->generateXml();
         break;
     case GraphicMode:
+    case Unknown:
         break;
     }
 #endif
@@ -236,10 +318,13 @@ void SieveEditorWidget::slotSaveAs()
 {
     switch (mMode) {
     case TextMode:
-        mTextModeWidget->slotSaveAs();
+        mTextModeWidget->saveAs(mScriptName->text());
         break;
     case GraphicMode:
-        mGraphicalModeWidget->slotSaveAs();
+        mGraphicalModeWidget->saveAs(mScriptName->text());
+        break;
+    case Unknown:
+        qDebug()<<" Unknown mode";
         break;
     }
 }
@@ -253,6 +338,9 @@ void SieveEditorWidget::slotImport()
     case GraphicMode:
         mGraphicalModeWidget->slotImport();
         break;
+    case Unknown:
+        qDebug()<<" Unknown mode";
+        break;
     }
 }
 
@@ -290,6 +378,9 @@ void SieveEditorWidget::slotSwitchMode()
         mTextModeWidget->setScript(script);
         break;
     }
+    case Unknown:
+        qDebug()<<" Unknown mode";
+        break;
     }
 }
 
