@@ -215,16 +215,20 @@ void QuickSearchLine::slotMoreOptionClicked(bool b)
 
 void QuickSearchLine::slotSearchEditTextEdited(const QString &text)
 {
-    if (text.isEmpty()) {
-        mExtraOption->hide();
-    } else {
-        if (text.trimmed().isEmpty()) {
+    int minimumStringLength = 3;
+    if (text.startsWith(QLatin1Char('"')) && text.endsWith(QLatin1Char('"'))) {
+        minimumStringLength = 5;
+    }
+    if (!text.trimmed().isEmpty()) {
+        if (text.length() > minimumStringLength) {
+            mExtraOption->show();
+            Q_EMIT searchEditTextEdited(text);
+        } else {
             mExtraOption->hide();
-            return;
         }
-        mExtraOption->show();
+    } else {
+        mExtraOption->hide();
     }
-    Q_EMIT searchEditTextEdited(text);
 }
 
 void QuickSearchLine::slotClearButtonClicked()
@@ -265,8 +269,11 @@ QuickSearchLine::SearchOptions QuickSearchLine::searchOptions() const
     return searchOptions;
 }
 
-void QuickSearchLine::focusQuickSearch()
+void QuickSearchLine::focusQuickSearch(const QString &selectedText)
 {
+    if (!selectedText.isEmpty()) {
+        mSearchEdit->setText(selectedText);
+    }
     mSearchEdit->setFocus();
 }
 
@@ -306,6 +313,11 @@ void QuickSearchLine::resetFilter()
         mTagFilterCombo->setCurrentIndex( 0 );
     mLockSearch->setChecked(false);
     mSearchEveryWhere->setChecked(true);
+    mSearchAgainstBody->setChecked(false);
+    mSearchAgainstSubject->setChecked(false);
+    mSearchAgainstFromOrTo->setChecked(false);
+    mSearchAgainstBcc->setChecked(false);
+
     mExtraOption->hide();
 }
 
@@ -414,7 +426,7 @@ QList<Akonadi::MessageStatus> QuickSearchLine::status() const
 
 void QuickSearchLine::updateComboboxVisibility()
 {
-    mTagFilterCombo->setVisible(mSearchEdit->isVisible() && mTagFilterCombo->count());
+    mTagFilterCombo->setVisible(!mSearchEdit->isHidden() && mTagFilterCombo->count());
 }
 
 bool QuickSearchLine::eventFilter(QObject *object, QEvent *e)
