@@ -23,12 +23,13 @@
 #include <Akonadi/EntityTreeModel>
 #include <QStandardItemModel>
 #include <kcalcore/todo.h>
+#include <KPushButton>
+#include <KMessageWidget>
 #include <qtest_kde.h>
 #include <qtestkeyboard.h>
 #include <qtestmouse.h>
 
 #include <QLineEdit>
-#include <QToolButton>
 #include <QHBoxLayout>
 #include <QShortcut>
 #include <QAction>
@@ -70,6 +71,12 @@ void TodoEditTest::shouldHaveDefaultValuesOnCreation()
     //QVERIFY(edit.collection().isValid());
     QVERIFY(!edit.message());
     QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    KPushButton *openEditor = qFindChild<KPushButton *>(&edit, QLatin1String("open-editor-button"));
+    KPushButton *save = qFindChild<KPushButton *>(&edit, QLatin1String("save-button"));
+    QVERIFY(openEditor);
+    QVERIFY(save);
+    QCOMPARE(openEditor->isEnabled(), false);
+    QCOMPARE(save->isEnabled(), false);
     QVERIFY(noteedit);
     QCOMPARE(noteedit->text(), QString());
 }
@@ -289,7 +296,7 @@ void TodoEditTest::shouldHideWidgetWhenClickOnCloseButton()
     edit.show();
     QTest::qWaitForWindowShown(&edit);
     QVERIFY(edit.isVisible());
-    QToolButton *close = qFindChild<QToolButton *>(&edit, QLatin1String("close-button"));
+    KPushButton *close = qFindChild<KPushButton *>(&edit, QLatin1String("close-button"));
     QTest::mouseClick(close, Qt::LeftButton);
     QCOMPARE(edit.isVisible(), false);
 }
@@ -306,13 +313,27 @@ void TodoEditTest::shouldHideWidgetWhenPressEscape()
     QCOMPARE(edit.isVisible(), false);
 }
 
+void TodoEditTest::shouldHideWidgetWhenSaveClicked()
+{
+    MessageViewer::TodoEdit edit;
+    edit.show();
+    QTest::qWaitForWindowShown(&edit);
+
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test Note"), "us-ascii");
+    edit.setMessage(msg);
+    KPushButton *save = qFindChild<KPushButton *>(&edit, QLatin1String("save-button"));
+    QTest::mouseClick(save, Qt::LeftButton);
+    QCOMPARE(edit.isVisible(), true);
+}
+
 void TodoEditTest::shouldSaveCollectionSettings()
 {
     MessageViewer::TodoEdit edit;
     Akonadi::CollectionComboBox *akonadicombobox = qFindChild<Akonadi::CollectionComboBox *>(&edit, QLatin1String("akonadicombobox"));
     akonadicombobox->setCurrentIndex(3);
     const Akonadi::Collection::Id id = akonadicombobox->currentCollection().id();
-    QToolButton *close = qFindChild<QToolButton *>(&edit, QLatin1String("close-button"));
+    KPushButton *close = qFindChild<KPushButton *>(&edit, QLatin1String("close-button"));
     QTest::mouseClick(close, Qt::LeftButton);
     QCOMPARE(MessageViewer::GlobalSettingsBase::self()->lastSelectedFolder(), id);
 }
@@ -391,4 +412,99 @@ void TodoEditTest::shouldHaveLineEditFocus()
     QCOMPARE(noteedit->hasFocus(), true);
 }
 
+void TodoEditTest::shouldShowMessageWidget()
+{
+    MessageViewer::TodoEdit edit;
+    edit.show();
+    QTest::qWaitForWindowShown(&edit);
+
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test note"), "us-ascii");
+    edit.setMessage(msg);
+    QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    noteedit->setText(QLatin1String("Test Note"));
+    KMessageWidget *msgwidget = qFindChild<KMessageWidget *>(&edit, QLatin1String("msgwidget"));
+    QCOMPARE(msgwidget->isVisible(), false);
+    QTest::keyClick(noteedit, Qt::Key_Enter);
+    QCOMPARE(msgwidget->isVisible(), true);
+}
+
+void TodoEditTest::shouldHideMessageWidget()
+{
+    MessageViewer::TodoEdit edit;
+    edit.show();
+    QTest::qWaitForWindowShown(&edit);
+    QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    noteedit->setText(QLatin1String("Test note"));
+
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test note"), "us-ascii");
+    edit.setMessage(msg);
+    KMessageWidget *msgwidget = qFindChild<KMessageWidget *>(&edit, QLatin1String("msgwidget"));
+    msgwidget->show();
+    QCOMPARE(msgwidget->isVisible(), true);
+    noteedit->setText(QLatin1String("Another note"));
+    QCOMPARE(msgwidget->isVisible(), false);
+}
+
+void TodoEditTest::shouldHideMessageWidgetWhenAddNewMessage()
+{
+    MessageViewer::TodoEdit edit;
+    edit.show();
+    QTest::qWaitForWindowShown(&edit);
+
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test note"), "us-ascii");
+    edit.setMessage(msg);
+    QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    noteedit->setText(QLatin1String("Test Note"));
+    KMessageWidget *msgwidget = qFindChild<KMessageWidget *>(&edit, QLatin1String("msgwidget"));
+    QTest::keyClick(noteedit, Qt::Key_Enter);
+    QCOMPARE(msgwidget->isVisible(), true);
+
+    KMime::Message::Ptr msg2(new KMime::Message);
+    msg2->subject(true)->fromUnicodeString(QLatin1String("Test note 2"), "us-ascii");
+    edit.setMessage(msg2);
+    QCOMPARE(msgwidget->isVisible(), false);
+}
+
+void TodoEditTest::shouldHideMessageWidgetWhenCloseWidget()
+{
+    MessageViewer::TodoEdit edit;
+    edit.show();
+    QTest::qWaitForWindowShown(&edit);
+
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test note"), "us-ascii");
+    edit.setMessage(msg);
+    QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    noteedit->setText(QLatin1String("Test Note"));
+    KMessageWidget *msgwidget = qFindChild<KMessageWidget *>(&edit, QLatin1String("msgwidget"));
+    QTest::keyClick(noteedit, Qt::Key_Enter);
+    QCOMPARE(msgwidget->isVisible(), true);
+    edit.slotCloseWidget();
+
+    QCOMPARE(msgwidget->isHidden(), true);
+}
+
+void TodoEditTest::shouldShouldEnabledSaveOpenEditorButton()
+{
+    MessageViewer::TodoEdit edit;
+    KMime::Message::Ptr msg(new KMime::Message);
+    msg->subject(true)->fromUnicodeString(QLatin1String("Test note"), "us-ascii");
+    edit.setMessage(msg);
+
+    QLineEdit *noteedit = qFindChild<QLineEdit *>(&edit, QLatin1String("noteedit"));
+    KPushButton *openEditor = qFindChild<KPushButton *>(&edit, QLatin1String("open-editor-button"));
+    KPushButton *save = qFindChild<KPushButton *>(&edit, QLatin1String("save-button"));
+    QCOMPARE(openEditor->isEnabled(), true);
+    QCOMPARE(save->isEnabled(), true);
+    noteedit->clear();
+
+    QCOMPARE(openEditor->isEnabled(), false);
+    QCOMPARE(save->isEnabled(), false);
+}
+
+
+
 QTEST_KDEMAIN( TodoEditTest, GUI )
