@@ -48,6 +48,7 @@ private slots:
     void shouldEmitCorrectCollection();
     void shouldHideWidgetWhenClickOnCloseButton();
     void shouldHideWidgetWhenPressEscape();
+    void shouldHideWidgetWhenSaveClicked();
     void shouldSaveCollectionSettings();
     void shouldSaveCollectionSettingsWhenCloseWidget();
     void shouldNotEmitTodoWhenMessageIsNull();
@@ -55,6 +56,11 @@ private slots:
     void shouldEmitNotEmitTodoWhenTextTrimmedIsEmpty();
     void shouldSaveCollectionSettingsWhenDeleteWidget();
     void shouldSetFocusWhenWeCallTodoEdit();
+    void shouldShowMessageWidget();
+    void shouldHideMessageWidget();
+    void shouldHideMessageWidgetWhenAddNewMessage();
+    void shouldHideMessageWidgetWhenCloseWidget();
+    void shouldShouldEnabledSaveOpenEditorButton();
 };
 
 #endif // TODOEDITTEST_H
