@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,14 +24,11 @@
 class QWidget;
 namespace NoteShared
 {
-class NOTESHARED_EXPORT NoteUtils
-{
-public:
-    NoteUtils();
-    bool sendToMail(QWidget *parent, const QString &title, const QString &message);
-    void sendToNetwork(QWidget *parent, const QString &title, const QString &message);
-    QString createToolTip(const Akonadi::Item &item);
-};
+namespace NoteUtils {
+NOTESHARED_EXPORT bool sendToMail(QWidget *parent, const QString &title, const QString &message);
+NOTESHARED_EXPORT void sendToNetwork(QWidget *parent, const QString &title, const QString &message);
+NOTESHARED_EXPORT QString createToolTip(const Akonadi::Item &item);
+}
 }
 
 #endif // NOTEUTILS_H
