@@ -1,15 +1,15 @@
 /*
   Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>
-  
+
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
   published by the Free Software Foundation.
-  
+
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -20,11 +20,12 @@
 
 #include "pimcommon/util/createresource.h"
 
-#include <KZip>
-#include <KTempDir>
 #include <KStandardDirs>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KArchiveDirectory>
+#include <KArchiveEntry>
+#include <KZip>
 
 #include <QFile>
 #include <QDir>
@@ -43,19 +44,32 @@ ImportCalendarJob::~ImportCalendarJob()
 
 void ImportCalendarJob::start()
 {
-    Q_EMIT title(i18n("Start import korganizer settings..."));
+    Q_EMIT title(i18n("Start import KOrganizer settings..."));
     mArchiveDirectory = archive()->directory();
-    searchAllFiles(mArchiveDirectory, QString());
-    if (mTypeSelected & Utils::Resources)
-        restoreResources();
-    if (mTypeSelected & Utils::Config)
-        restoreConfig();
+    searchAllFiles(mArchiveDirectory ,QString());
+    initializeListStep();
+    nextStep();
+}
+
+void ImportCalendarJob::nextStep()
+{
+    ++mIndex;
+    if (mIndex < mListStep.count()) {
+        Utils::StoredType type = mListStep.at(mIndex);
+        if (type == Utils::Resources)
+            restoreResources();
+        if (type == Utils::Config)
+            restoreConfig();
+    } else {
+        Q_EMIT jobFinished();
+    }
 }
 
 void ImportCalendarJob::restoreResources()
 {
     Q_EMIT info(i18n("Restore resources..."));
-    restoreResourceFile(QString::fromLatin1("akonadi_ical_resource"), Utils::calendarPath(), storeCalendar);
+    QStringList listResource;
+    listResource << restoreResourceFile(QString::fromLatin1("akonadi_ical_resource"), Utils::calendarPath(), storeCalendar);
 
     if (!mListResourceFile.isEmpty()) {
         QDir dir(mTempDirName);
@@ -103,11 +117,14 @@ void ImportCalendarJob::restoreResources()
 
                     const QString newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_icaldir_resource"), filename, settings, true );
                     infoAboutNewResource(newResource);
+                    listResource << newResource;
                     qDebug()<<" newResource"<<newResource;
                 }
             }
         }
     }
+    //It's maildir support. Need to add support
+    startSynchronizeResources(listResource);
 }
 
 void ImportCalendarJob::addSpecificResourceSettings(KSharedConfig::Ptr resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings)
@@ -174,17 +191,31 @@ void ImportCalendarJob::storeCalendarArchiveResource(const KArchiveDirectory *di
 
 void ImportCalendarJob::restoreConfig()
 {
-    const QString korganizerPrinterrcStr(QLatin1String("korganizer_printing.rc"));
-    const KArchiveEntry* korganizerPrinterEntry  = mArchiveDirectory->entry(Utils::configsPath() + korganizerPrinterrcStr);
-    if (korganizerPrinterEntry && korganizerPrinterEntry->isFile()) {
-        const KArchiveFile* korganizerFile = static_cast<const KArchiveFile*>(korganizerPrinterEntry);
-        const QString korganizerPrinterrc = KStandardDirs::locateLocal( "config",  korganizerPrinterrcStr);
-        if (QFile(korganizerPrinterrc).exists()) {
-            if (overwriteConfigMessageBox(korganizerPrinterrcStr)) {
-                copyToFile(korganizerFile, korganizerPrinterrc, korganizerPrinterrcStr, Utils::configsPath());
+    const QString korganizerPrinterrcStr(QLatin1String("calendar_printing.rc"));
+    const QString oldKorganizerPrintrrcStr(QLatin1String("korganizer_printing.rc"));
+    const KArchiveEntry* oldKorganizerPrinterEntry  = mArchiveDirectory->entry(Utils::configsPath() + oldKorganizerPrintrrcStr);
+    if (oldKorganizerPrinterEntry && oldKorganizerPrinterEntry->isFile()) {
+        const KArchiveFile* korganizerFile = static_cast<const KArchiveFile*>(oldKorganizerPrinterEntry);
+        const QString oldKorganizerPrintrrc = KStandardDirs::locateLocal( "config",  korganizerPrinterrcStr);
+        if (QFile(oldKorganizerPrintrrc).exists()) {
+            if (overwriteConfigMessageBox(oldKorganizerPrintrrc)) {
+                copyToFile(korganizerFile, oldKorganizerPrintrrc, oldKorganizerPrintrrcStr, Utils::configsPath());
             }
         } else {
-            copyToFile(korganizerFile, korganizerPrinterrc, korganizerPrinterrcStr, Utils::configsPath());
+            copyToFile(korganizerFile, oldKorganizerPrintrrc, oldKorganizerPrintrrcStr, Utils::configsPath());
+        }
+    } else {
+        const KArchiveEntry* korganizerPrinterEntry  = mArchiveDirectory->entry(Utils::configsPath() + korganizerPrinterrcStr);
+        if (korganizerPrinterEntry && korganizerPrinterEntry->isFile()) {
+            const KArchiveFile* korganizerFile = static_cast<const KArchiveFile*>(korganizerPrinterEntry);
+            const QString korganizerPrinterrc = KStandardDirs::locateLocal( "config",  korganizerPrinterrcStr);
+            if (QFile(korganizerPrinterrc).exists()) {
+                if (overwriteConfigMessageBox(korganizerPrinterrcStr)) {
+                    copyToFile(korganizerFile, korganizerPrinterrc, korganizerPrinterrcStr, Utils::configsPath());
+                }
+            } else {
+                copyToFile(korganizerFile, korganizerPrinterrc, korganizerPrinterrcStr, Utils::configsPath());
+            }
         }
     }
 
@@ -243,6 +274,7 @@ void ImportCalendarJob::restoreConfig()
 
 
     Q_EMIT info(i18n("Config restored."));
+    nextStep();
 }
 
 void ImportCalendarJob::importkorganizerConfig(const KArchiveFile* file, const QString &config, const QString &filename,const QString &prefix)
@@ -261,4 +293,3 @@ void ImportCalendarJob::importkorganizerConfig(const KArchiveFile* file, const Q
 }
 
 
-#include "importcalendarjob.moc"
