@@ -21,7 +21,7 @@
 
 #include <Akonadi/AgentManager>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KStandardDirs>
 #include <KTemporaryFile>
 #include <KConfigGroup>
@@ -43,12 +43,13 @@ ExportJotJob::~ExportJotJob()
 
 void ExportJotJob::start()
 {
-    Q_EMIT title(i18n("Start export kjots settings..."));
+    Q_EMIT title(i18n("Start export KJots settings..."));
     mArchiveDirectory = archive()->directory();
     if (mTypeSelected & Utils::Resources) {
         backupResources();
         increaseProgressDialog();
         if (wasCanceled()) {
+            Q_EMIT jobFinished();
             return;
         }
     }
@@ -56,9 +57,11 @@ void ExportJotJob::start()
         backupConfig();
         increaseProgressDialog();
         if (wasCanceled()) {
+            Q_EMIT jobFinished();
             return;
         }
     }
+    Q_EMIT jobFinished();
 }
 
 void ExportJotJob::backupResources()
@@ -127,4 +130,3 @@ void ExportJotJob::backupConfig()
 
 }
 
-#include "exportjotjob.moc"
