@@ -331,7 +331,7 @@ void ImportMailJob::restoreResources()
                         mHashResources.insert(filename,newResource);
                         infoAboutNewResource(newResource);
                     }
-                } else if (filename.contains(QLatin1String("imap"))) {
+                } else if (filename.contains(QLatin1String("imap")) || filename.contains(QLatin1String("kolab_")) || filename.contains(QLatin1String("gmail_")) ) {
                     KConfigGroup network = resourceConfig->group(QLatin1String("network"));
                     if (network.hasKey(QLatin1String("Authentication"))) {
                         settings.insert(QLatin1String("Authentication"),network.readEntry("Authentication",1));
@@ -416,7 +416,14 @@ void ImportMailJob::restoreResources()
                         settings.insert(QLatin1String("SieveVacationFilename"),siever.readEntry("SieveVacationFilename"));
                     }
 
-                    const QString newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_imap_resource"), filename, settings );
+                    QString newResource;
+                    if (filename.contains(QLatin1String("kolab_"))) {
+                        newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_kolab_resource"), filename, settings );
+                    } else if (filename.contains(QLatin1String("gmail_"))) {
+                        newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_gmail_resource"), filename, settings );
+                    } else {
+                        newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_imap_resource"), filename, settings );
+                    }
                     if (!newResource.isEmpty()) {
                         mHashResources.insert(filename,newResource);
                         infoAboutNewResource(newResource);
