@@ -48,6 +48,7 @@ Q_SIGNALS:
     void updateStatusBarMessage(const QString &msg);
     void listFileWasInitialized();
     void selectionChanged();
+    void tabCountChanged(bool hasTab);
 
 public slots:
     void slotAuthenticate();
@@ -58,7 +59,7 @@ public slots:
     void slotDelete();
     void slotDownloadFile();
     void slotShowLog();
-
+    void slotRename();
 private slots:
     void slotUpdateIcon(const QIcon &icon, StorageServicePage *page);
 
